# Generated by Django 2.2.24 on 2024-02-15 15:47

import django.core.validators
from django.db import migrations, models
import django.db.models.deletion
import ishtar_common.models_common
import re


class Migration(migrations.Migration):

    dependencies = [
        ('ishtar_common', '0236_auto_20240218_1726'),
        ('archaeological_finds', '0114_auto_20231115_1617'),
    ]

    operations = [
        migrations.CreateModel(
            name='InventoryConformity',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('label', models.TextField(verbose_name='Label')),
                ('txt_idx', models.TextField(help_text='The slug is the standardized version of the name. It contains only lowercase letters, numbers and hyphens. Each slug must be unique.', unique=True, validators=[django.core.validators.RegexValidator(re.compile('^[-a-zA-Z0-9_]+\\Z'), "Enter a valid 'slug' consisting of letters, numbers, underscores or hyphens.", 'invalid')], verbose_name='Textual ID')),
                ('comment', models.TextField(blank=True, default='', verbose_name='Comment')),
                ('available', models.BooleanField(default=True, verbose_name='Available')),
                ('order', models.IntegerField(default=10, verbose_name='Order')),
            ],
            options={
                'verbose_name': 'Inventory conformity type',
                'verbose_name_plural': 'Inventory conformity types',
                'ordering': ('order', 'label'),
            },
            bases=(ishtar_common.models_common.Cached, models.Model),
        ),
        migrations.CreateModel(
            name='InventoryMarkingPresence',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('label', models.TextField(verbose_name='Label')),
                ('txt_idx', models.TextField(help_text='The slug is the standardized version of the name. It contains only lowercase letters, numbers and hyphens. Each slug must be unique.', unique=True, validators=[django.core.validators.RegexValidator(re.compile('^[-a-zA-Z0-9_]+\\Z'), "Enter a valid 'slug' consisting of letters, numbers, underscores or hyphens.", 'invalid')], verbose_name='Textual ID')),
                ('comment', models.TextField(blank=True, default='', verbose_name='Comment')),
                ('available', models.BooleanField(default=True, verbose_name='Available')),
                ('order', models.IntegerField(default=10, verbose_name='Order')),
            ],
            options={
                'verbose_name': 'Presence of inventory marking type',
                'verbose_name_plural': 'Presence of inventory marking types',
                'ordering': ('order', 'label'),
            },
            bases=(ishtar_common.models_common.Cached, models.Model),
        ),
        migrations.CreateModel(
            name='MarkingType',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('label', models.TextField(verbose_name='Label')),
                ('txt_idx', models.TextField(help_text='The slug is the standardized version of the name. It contains only lowercase letters, numbers and hyphens. Each slug must be unique.', unique=True, validators=[django.core.validators.RegexValidator(re.compile('^[-a-zA-Z0-9_]+\\Z'), "Enter a valid 'slug' consisting of letters, numbers, underscores or hyphens.", 'invalid')], verbose_name='Textual ID')),
                ('comment', models.TextField(blank=True, default='', verbose_name='Comment')),
                ('available', models.BooleanField(default=True, verbose_name='Available')),
                ('order', models.IntegerField(default=10, verbose_name='Order')),
            ],
            options={
                'verbose_name': 'Marking type',
                'verbose_name_plural': 'Marking types',
                'ordering': ('order', 'label'),
            },
            bases=(ishtar_common.models_common.Cached, models.Model),
        ),
        migrations.CreateModel(
            name='MuseumCollection',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('label', models.TextField(verbose_name='Label')),
                ('txt_idx', models.TextField(help_text='The slug is the standardized version of the name. It contains only lowercase letters, numbers and hyphens. Each slug must be unique.', unique=True, validators=[django.core.validators.RegexValidator(re.compile('^[-a-zA-Z0-9_]+\\Z'), "Enter a valid 'slug' consisting of letters, numbers, underscores or hyphens.", 'invalid')], verbose_name='Textual ID')),
                ('comment', models.TextField(blank=True, default='', verbose_name='Comment')),
                ('available', models.BooleanField(default=True, verbose_name='Available')),
                ('order', models.IntegerField(default=10, verbose_name='Order')),
            ],
            options={
                'verbose_name': 'Museum collection',
                'verbose_name_plural': 'Museum collections',
                'ordering': ('order', 'label'),
            },
            bases=(ishtar_common.models_common.Cached, models.Model),
        ),
        migrations.CreateModel(
            name='OriginalReproduction',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('label', models.TextField(verbose_name='Label')),
                ('txt_idx', models.TextField(help_text='The slug is the standardized version of the name. It contains only lowercase letters, numbers and hyphens. Each slug must be unique.', unique=True, validators=[django.core.validators.RegexValidator(re.compile('^[-a-zA-Z0-9_]+\\Z'), "Enter a valid 'slug' consisting of letters, numbers, underscores or hyphens.", 'invalid')], verbose_name='Textual ID')),
                ('comment', models.TextField(blank=True, default='', verbose_name='Comment')),
                ('available', models.BooleanField(default=True, verbose_name='Available')),
                ('order', models.IntegerField(default=10, verbose_name='Order')),
            ],
            options={
                'verbose_name': 'Original/reproduction type',
                'verbose_name_plural': 'Original/reproduction types',
                'ordering': ('order', 'label'),
            },
            bases=(ishtar_common.models_common.Cached, models.Model),
        ),
        migrations.AddField(
            model_name='find',
            name='cache_complete_museum_id',
            field=models.TextField(blank=True, db_index=True, default='', help_text='Cached value - do not edit', verbose_name='Complete museum ID'),
        ),
        migrations.AddField(
            model_name='find',
            name='museum_allocation_date',
            field=models.DateField(blank=True, null=True, verbose_name='Date of museum allocation'),
        ),
        migrations.AddField(
            model_name='find',
            name='museum_custodian_institution',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='deposited', to='ishtar_common.Organization', verbose_name='Custodian institution'),
        ),
        migrations.AddField(
            model_name='find',
            name='museum_depositor_inventory_number',
            field=models.TextField(blank=True, default='', verbose_name='Depositor inventory number'),
        ),
        migrations.AddField(
            model_name='find',
            name='museum_donor',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='has_provided', to='ishtar_common.BiographicalNote', verbose_name='Donor, testator or vendor'),
        ),
        migrations.AddField(
            model_name='find',
            name='museum_entry_date',
            field=models.DateField(blank=True, null=True, verbose_name='Museum entry date (exact or start)'),
        ),
        migrations.AddField(
            model_name='find',
            name='museum_entry_date_comment',
            field=models.TextField(blank=True, default='', verbose_name='Comment on museum entry date'),
        ),
        migrations.AddField(
            model_name='find',
            name='museum_entry_date_end',
            field=models.DateField(blank=True, null=True, verbose_name='Museum entry date (end)'),
        ),
        migrations.AddField(
            model_name='find',
            name='museum_entry_mode_comment',
            field=models.TextField(blank=True, default='', verbose_name='Comment on museum entry mode'),
        ),
        migrations.AddField(
            model_name='find',
            name='museum_former_collections',
            field=models.ManyToManyField(blank=True, related_name='finds_former_collections', to='ishtar_common.BiographicalNote', verbose_name='Former collection'),
        ),
        migrations.AddField(
            model_name='find',
            name='museum_id_comment',
            field=models.TextField(blank=True, default='', verbose_name='Comment on museum ID'),
        ),
        migrations.AddField(
            model_name='find',
            name='museum_id_prefix',
            field=models.TextField(blank=True, default='', verbose_name='Museum ID prefix'),
        ),
        migrations.AddField(
            model_name='find',
            name='museum_id_suffix',
            field=models.TextField(blank=True, default='', verbose_name='Museum ID suffix'),
        ),
        migrations.AddField(
            model_name='find',
            name='museum_inventory_entry_year',
            field=models.PositiveIntegerField(blank=True, null=True, verbose_name='Inventory entry year'),
        ),
        migrations.AddField(
            model_name='find',
            name='museum_inventory_transcript',
            field=models.TextField(blank=True, default='', verbose_name='Inventory transcript'),
        ),
        migrations.AddField(
            model_name='find',
            name='museum_marking_comment',
            field=models.TextField(blank=True, default='', verbose_name='Comment on marking'),
        ),
        migrations.AddField(
            model_name='find',
            name='museum_non_conformity_comment',
            field=models.TextField(blank=True, default='', verbose_name='Comment of non-conformity'),
        ),
        migrations.AddField(
            model_name='find',
            name='museum_owner_institution',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='owns', to='ishtar_common.Organization', verbose_name='Owner institution'),
        ),
        migrations.AddField(
            model_name='find',
            name='museum_purchase_price',
            field=models.TextField(blank=True, default='', verbose_name='Purchase price'),
        ),
        migrations.AddField(
            model_name='find',
            name='quantity_comment',
            field=models.TextField(blank=True, default='', verbose_name='Comment on quantity'),
        ),
        migrations.AddField(
            model_name='historicalfind',
            name='cache_complete_museum_id',
            field=models.TextField(blank=True, db_index=True, default='', help_text='Cached value - do not edit', verbose_name='Complete museum ID'),
        ),
        migrations.AddField(
            model_name='historicalfind',
            name='museum_allocation_date',
            field=models.DateField(blank=True, null=True, verbose_name='Date of museum allocation'),
        ),
        migrations.AddField(
            model_name='historicalfind',
            name='museum_custodian_institution',
            field=models.ForeignKey(blank=True, db_constraint=False, null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='+', to='ishtar_common.Organization', verbose_name='Custodian institution'),
        ),
        migrations.AddField(
            model_name='historicalfind',
            name='museum_depositor_inventory_number',
            field=models.TextField(blank=True, default='', verbose_name='Depositor inventory number'),
        ),
        migrations.AddField(
            model_name='historicalfind',
            name='museum_donor',
            field=models.ForeignKey(blank=True, db_constraint=False, null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='+', to='ishtar_common.BiographicalNote', verbose_name='Donor, testator or vendor'),
        ),
        migrations.AddField(
            model_name='historicalfind',
            name='museum_entry_date',
            field=models.DateField(blank=True, null=True, verbose_name='Museum entry date (exact or start)'),
        ),
        migrations.AddField(
            model_name='historicalfind',
            name='museum_entry_date_comment',
            field=models.TextField(blank=True, default='', verbose_name='Comment on museum entry date'),
        ),
        migrations.AddField(
            model_name='historicalfind',
            name='museum_entry_date_end',
            field=models.DateField(blank=True, null=True, verbose_name='Museum entry date (end)'),
        ),
        migrations.AddField(
            model_name='historicalfind',
            name='museum_entry_mode_comment',
            field=models.TextField(blank=True, default='', verbose_name='Comment on museum entry mode'),
        ),
        migrations.AddField(
            model_name='historicalfind',
            name='museum_id_comment',
            field=models.TextField(blank=True, default='', verbose_name='Comment on museum ID'),
        ),
        migrations.AddField(
            model_name='historicalfind',
            name='museum_id_prefix',
            field=models.TextField(blank=True, default='', verbose_name='Museum ID prefix'),
        ),
        migrations.AddField(
            model_name='historicalfind',
            name='museum_id_suffix',
            field=models.TextField(blank=True, default='', verbose_name='Museum ID suffix'),
        ),
        migrations.AddField(
            model_name='historicalfind',
            name='museum_inventory_entry_year',
            field=models.PositiveIntegerField(blank=True, null=True, verbose_name='Inventory entry year'),
        ),
        migrations.AddField(
            model_name='historicalfind',
            name='museum_inventory_transcript',
            field=models.TextField(blank=True, default='', verbose_name='Inventory transcript'),
        ),
        migrations.AddField(
            model_name='historicalfind',
            name='museum_marking_comment',
            field=models.TextField(blank=True, default='', verbose_name='Comment on marking'),
        ),
        migrations.AddField(
            model_name='historicalfind',
            name='museum_non_conformity_comment',
            field=models.TextField(blank=True, default='', verbose_name='Comment of non-conformity'),
        ),
        migrations.AddField(
            model_name='historicalfind',
            name='museum_owner_institution',
            field=models.ForeignKey(blank=True, db_constraint=False, null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='+', to='ishtar_common.Organization', verbose_name='Owner institution'),
        ),
        migrations.AddField(
            model_name='historicalfind',
            name='museum_purchase_price',
            field=models.TextField(blank=True, default='', verbose_name='Purchase price'),
        ),
        migrations.AddField(
            model_name='historicalfind',
            name='quantity_comment',
            field=models.TextField(blank=True, default='', verbose_name='Comment on quantity'),
        ),
        migrations.AlterField(
            model_name='find',
            name='functional_areas',
            field=models.ManyToManyField(blank=True, related_name='find', to='archaeological_finds.FunctionalArea', verbose_name='Functional areas'),
        ),
        migrations.AlterField(
            model_name='find',
            name='museum_id',
            field=models.TextField(blank=True, default='', verbose_name='Museum ID'),
        ),
        migrations.AlterField(
            model_name='historicalfind',
            name='museum_id',
            field=models.TextField(blank=True, default='', verbose_name='Museum ID'),
        ),
        migrations.CreateModel(
            name='TechnicalProcessType',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('label', models.TextField(verbose_name='Label')),
                ('txt_idx', models.TextField(help_text='The slug is the standardized version of the name. It contains only lowercase letters, numbers and hyphens. Each slug must be unique.', unique=True, validators=[django.core.validators.RegexValidator(re.compile('^[-a-zA-Z0-9_]+\\Z'), "Enter a valid 'slug' consisting of letters, numbers, underscores or hyphens.", 'invalid')], verbose_name='Textual ID')),
                ('comment', models.TextField(blank=True, default='', verbose_name='Comment')),
                ('available', models.BooleanField(default=True, verbose_name='Available')),
                ('order', models.IntegerField(default=10, verbose_name='Order')),
                ('parent', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='archaeological_finds.TechnicalProcessType', verbose_name='Parent')),
            ],
            options={
                'verbose_name': 'Technical process type',
                'verbose_name_plural': 'Technical process types',
                'ordering': ('order', 'parent__label', 'label'),
            },
            bases=(ishtar_common.models_common.Cached, models.Model),
        ),
        migrations.CreateModel(
            name='TechnicalAreaType',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('label', models.TextField(verbose_name='Label')),
                ('txt_idx', models.TextField(help_text='The slug is the standardized version of the name. It contains only lowercase letters, numbers and hyphens. Each slug must be unique.', unique=True, validators=[django.core.validators.RegexValidator(re.compile('^[-a-zA-Z0-9_]+\\Z'), "Enter a valid 'slug' consisting of letters, numbers, underscores or hyphens.", 'invalid')], verbose_name='Textual ID')),
                ('comment', models.TextField(blank=True, default='', verbose_name='Comment')),
                ('available', models.BooleanField(default=True, verbose_name='Available')),
                ('order', models.IntegerField(default=10, verbose_name='Order')),
                ('parent', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='archaeological_finds.TechnicalAreaType', verbose_name='Parent')),
            ],
            options={
                'verbose_name': 'Technical area type',
                'verbose_name_plural': 'Technical area types',
                'ordering': ('order', 'parent__label', 'label'),
            },
            bases=(ishtar_common.models_common.Cached, models.Model),
        ),
        migrations.CreateModel(
            name='CollectionEntryModeType',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('label', models.TextField(verbose_name='Label')),
                ('txt_idx', models.TextField(help_text='The slug is the standardized version of the name. It contains only lowercase letters, numbers and hyphens. Each slug must be unique.', unique=True, validators=[django.core.validators.RegexValidator(re.compile('^[-a-zA-Z0-9_]+\\Z'), "Enter a valid 'slug' consisting of letters, numbers, underscores or hyphens.", 'invalid')], verbose_name='Textual ID')),
                ('comment', models.TextField(blank=True, default='', verbose_name='Comment')),
                ('available', models.BooleanField(default=True, verbose_name='Available')),
                ('order', models.IntegerField(default=10, verbose_name='Order')),
                ('parent', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='archaeological_finds.CollectionEntryModeType', verbose_name='Parent')),
            ],
            options={
                'verbose_name': 'Collection entry mode type',
                'verbose_name_plural': 'Collection entry mode types',
                'ordering': ('order', 'parent__label', 'label'),
            },
            bases=(ishtar_common.models_common.Cached, models.Model),
        ),
        migrations.AddField(
            model_name='find',
            name='museum_collection',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='current_collection_of', to='archaeological_finds.MuseumCollection', verbose_name='Collection'),
        ),
        migrations.AddField(
            model_name='find',
            name='museum_collection_entry_mode',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='archaeological_finds.CollectionEntryModeType', verbose_name='Collections entry mode'),
        ),
        migrations.AddField(
            model_name='find',
            name='museum_inventory_conformity',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='archaeological_finds.InventoryConformity', verbose_name='Conformity with inventory'),
        ),
        migrations.AddField(
            model_name='find',
            name='museum_inventory_marking_presence',
            field=models.ManyToManyField(blank=True, related_name='finds', to='archaeological_finds.InventoryMarkingPresence', verbose_name='Presence of inventory marking'),
        ),
        migrations.AddField(
            model_name='find',
            name='museum_marking_type',
            field=models.ManyToManyField(blank=True, related_name='finds', to='archaeological_finds.MarkingType', verbose_name='Type of marking'),
        ),
        migrations.AddField(
            model_name='find',
            name='museum_original_repro',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='archaeological_finds.OriginalReproduction', verbose_name='Original/reproduction'),
        ),
        migrations.AddField(
            model_name='find',
            name='technical_areas',
            field=models.ManyToManyField(blank=True, related_name='find', to='archaeological_finds.TechnicalAreaType', verbose_name='Technical areas'),
        ),
        migrations.AddField(
            model_name='find',
            name='technical_processes',
            field=models.ManyToManyField(blank=True, related_name='find', to='archaeological_finds.TechnicalProcessType', verbose_name='Technical processes'),
        ),
        migrations.AddField(
            model_name='historicalfind',
            name='museum_collection',
            field=models.ForeignKey(blank=True, db_constraint=False, null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='+', to='archaeological_finds.MuseumCollection', verbose_name='Collection'),
        ),
        migrations.AddField(
            model_name='historicalfind',
            name='museum_collection_entry_mode',
            field=models.ForeignKey(blank=True, db_constraint=False, null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='+', to='archaeological_finds.CollectionEntryModeType', verbose_name='Collections entry mode'),
        ),
        migrations.AddField(
            model_name='historicalfind',
            name='museum_inventory_conformity',
            field=models.ForeignKey(blank=True, db_constraint=False, null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='+', to='archaeological_finds.InventoryConformity', verbose_name='Conformity with inventory'),
        ),
        migrations.AddField(
            model_name='historicalfind',
            name='museum_original_repro',
            field=models.ForeignKey(blank=True, db_constraint=False, null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='+', to='archaeological_finds.OriginalReproduction', verbose_name='Original/reproduction'),
        ),
    ]
